// animate.js
// Created by: Jeff Rackauckas & Chris Rackauckas

// This file contains the information for animating the map.




function updateDisplays(){
	generateThresholdDescriptions();
	document.getElementById("day").innerHTML = curTime.format('L');
	document.getElementById("parameterColorSpan").innerHTML = parameterColor;
	document.getElementById("parameterSizeSpan").innerHTML = parameterSize;
	document.getElementById("parameterColorDescriptionSpan").innerHTML = parameterDescriptions[parameterColor];
	document.getElementById("parameterSizeDescriptionSpan").innerHTML = parameterDescriptions[parameterSize];
	document.getElementById("greenThresholdSpan").innerHTML = greenThreshold;
	document.getElementById("yellowThresholdSpan").innerHTML = yellowThreshold;
	document.getElementById("redThresholdSpan").innerHTML = redThreshold;
	document.getElementById("largeThresholdSpan").innerHTML = largeThreshold;
	document.getElementById("mediumThresholdSpan").innerHTML = mediumThreshold;
	document.getElementById("smallThresholdSpan").innerHTML = smallThreshold;
	
	createStationDisplays(stationInformation,true);
	chooseDisplayedMarkers(markerArray);
}

//Updates the parameter to match the selection. Called on change in the selection box.
function updateSelect(){
  parameterColor = document.getElementById("parameterColorSelect").value;
  parameterSize  = document.getElementById("parameterSizeSelect").value;
  updateDisplays();
  reset();
}
function updateDelay(){
	delay = document.getElementById("delaySlider").value;
}

function setDay(){
	pause();
	var day = document.getElementById("setDayTxt").value;
	curTime = moment(day);
	updateDisplays();
}

function updateStayTime(){
	stayTime = document.getElementById("stayTimeSlider").value;
}

function updateShowLabels(){
	showLabels = document.getElementById("showLabels").checked;
	updateDisplays();
}
function generateThresholdDescriptions(){
	
	// Color Descriptions
	
	if(parameterThresholds[parameterColor][0] < parameterThresholds[parameterColor][1]){
		greenThreshold = "&gt; " + parameterThresholds[parameterColor][1];
		yellowThreshold = "&gt; " + parameterThresholds[parameterColor][0] + " but &lt; " + parameterThresholds[parameterColor][1];
		redThreshold = "&lt; " + parameterThresholds[parameterColor][0]
	}
	if(parameterThresholds[parameterColor][0] > parameterThresholds[parameterColor][1]){
		greenThreshold = "&lt; " + parameterThresholds[parameterColor][1];
		yellowThreshold = "&lt; " + parameterThresholds[parameterColor][0] + " but &gt; " + parameterThresholds[parameterColor][1];
		redThreshold = "&gt; " + parameterThresholds[parameterColor][0]
	}
	
	//Size Descriptions
	
	if(parameterThresholds[parameterSize][0] < parameterThresholds[parameterSize][1]){
		largeThreshold = "&gt; " + parameterThresholds[parameterSize][1];
		mediumThreshold = "&gt; " + parameterThresholds[parameterSize][0] + " but &lt; " + parameterThresholds[parameterSize][1];
		smallThreshold = "&lt; " + parameterThresholds[parameterSize][0]
	}
	if(parameterThresholds[parameterSize][0] > parameterThresholds[parameterSize][1]){
		largeThreshold = "&lt; " + parameterThresholds[parameterSize][1];
		mediumThreshold = "&lt; " + parameterThresholds[parameterSize][0] + " but &gt; " + parameterThresholds[parameterSize][1];
		smallThreshold = "&gt; " + parameterThresholds[parameterSize][0]
	}
	
}

function stepForward(){
	if(curTime.diff(endDate,"days")<0){
	curTime.add('days', 1);
	}
	updateDisplays();
}

function stepBackward(){
	if(curTime.diff(startDate,"days")>0){
	curTime.subtract('days', 1);
	}
	updateDisplays();
}

function timerUpdate(){
	if(curTime.diff(endDate,"days")<0){
		curTime.add('days', 1);
		updateDisplays();
	}
	else{
		window.clearInterval(interval)
	}
}
function play(){
	interval = window.setInterval("timerUpdate()",delay);
}

function pause(){
	window.clearInterval(interval);
}

function reset(){
	window.clearInterval(interval);
	curTime=moment(defaultDate);
	updateDisplays();
	startTIndex = Array.apply(null, new Array(stationInformation.length)).map(Number.prototype.valueOf,0);
	deleteReadingsRows();
	markerArray = [];
}

function addReadingsRow(name,readingColor,readingSize,date,lat,long){
	rowsAdded++;
    var x=document.getElementById('ReadingsTable').insertRow(rowsAdded);
    var c1=x.insertCell(0);
    var c2=x.insertCell(1);
	var c3=x.insertCell(2);
	var c4=x.insertCell(3);
    c1.innerHTML="<div class=\"name\">" + name + "</div>";
    c2.innerHTML="<div class=\"readingColor\">" + readingColor + "</div>";
	c3.innerHTML="<div class=\"readingSize\">" + readingSize + "</div>";
	c4.innerHTML="<div class=\"date\">" + date + "</div>";
	
	x.onmouseover=function(){
		MOUSEOVER_STATE=true;
		pause();
		name = this.cells[0].innerHTML.replace(/<(?:.|\n)*?>/gm, '');
		date = this.cells[3].innerHTML.replace(/<(?:.|\n)*?>/gm, '');
		id = name + date;
		for(i=0;i<markerArray.length;i++){
			markerArray[i].setMoused(id); //By default, all are moused. When you scroll over one, all else are set to false.
		}
		updateDisplays();
	}
	
	x.onmouseout=function(){
		MOUSEOVER_STATE=false;
		for(i=0;i<markerArray.length;i++){
			markerArray[i].resetMoused(); //Sets moused to true for all
		}
		updateDisplays();
	}
}


function deleteReadingsRows(){
	var x=document.getElementById('ReadingsTable')
	for(i=rowsAdded;i>=1;i--){
		x.deleteRow(i);
	}
	rowsAdded=0;
}